@@ -1047,7 +1047,24 @@ class XlPath(type(pathlib.Path())):
         data = []
         # todo 这一步可能不够严谨，不同的操作系统文件格式不同。但使用splitlines也不太好，在数据含有NEL等特殊字符时会多换行。
         for line in s.split('\n'):
-            data.append(json.loads(line))
+            if line:
+                data.append(json.loads(line))
+
+        if return_mode:
+            return data, encoding
+        else:
+            return data
+
+    def read_csv(self, encoding='utf8', *, errors='strict', return_mode: bool = False,
+                 delimiter=',', quotechar='"', **kwargs):
+        """
+        :return:
+            data，n行m列的list
+        """
+        import csv
+
+        s, encoding = self.read_text(encoding=encoding, errors=errors, return_mode=True)
+        data = list(csv.reader(s.splitlines(), delimiter=delimiter, quotechar=quotechar, **kwargs))
 
         if return_mode:
             return data, encoding
